Interpolations (:mod:`kanon.tables.interpolations`)
===================================================

.. currentmodule:: kanon.tables.interpolations

.. automodule:: kanon.tables.interpolations
    :members:
